#
# spec file
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor ofi%nil

# Static libraries are disabled by default
# for non HPC builds
# To enable them, simply uncomment:
# % define build_static_devel 1

%define pname mpich
%define vers  4.2.2
%define _vers 4_2_2

%if "%{flavor}" == ""
ExclusiveArch:  do_not_build
%{bcond_with hpc}
%endif

%if "%{flavor}" == "standard"
%define build_flavor ucx
%{bcond_with hpc}
%endif
%if "%{flavor}" == "testsuite"
%define build_flavor ucx
%define testsuite 1
%{bcond_with hpc}
%endif

%if "%{flavor}" == "ofi"
%define build_flavor ofi
%{bcond_with hpc}
%endif
%if "%{flavor}" == "ofi-testsuite"
%define build_flavor ofi
%define testsuite 1
%{bcond_with hpc}
%endif

%if "%flavor" == "gnu-hpc"
%define compiler_family gnu
%undefine c_f_ver
%define build_flavor ucx
%define build_static_devel 1
%{bcond_without hpc}
%endif
%if "%flavor" == "gnu-hpc-testsuite"
%define compiler_family gnu
%undefine c_f_ver
%define testsuite 1
%define build_flavor ucx
%{bcond_without hpc}
%endif

%if "%flavor" == "gnu-hpc-ofi"
%define compiler_family gnu
%undefine c_f_ver
%define build_flavor ofi
%define build_static_devel 1
%{bcond_without hpc}
%endif
%if "%flavor" == "gnu-hpc-ofi-testsuite"
%define compiler_family gnu
%undefine c_f_ver
%define testsuite 1
%define build_flavor ofi
%{bcond_without hpc}
%endif

%if "%flavor" == "gnu7-hpc"
%define compiler_family gnu
%define c_f_ver 7
%define build_flavor ucx
%define build_static_devel 1
%{bcond_without hpc}
%endif

%if "%flavor" == "gnu7-hpc-testsuite"
%define compiler_family gnu
%define c_f_ver 7
%define testsuite 1
%define build_flavor ucx
%{bcond_without hpc}
%endif

%if "%flavor" == "gnu7-hpc-ofi"
%define compiler_family gnu
%define c_f_ver 7
%define build_flavor ofi
%define build_static_devel 1
%{bcond_without hpc}
%endif
%if "%flavor" == "gnu7-hpc-ofi-testsuite"
%define compiler_family gnu
%define c_f_ver 7
%define testsuite 1
%define build_flavor ofi
%{bcond_without hpc}
%endif

%if "%flavor" == "gnu8-hpc"
%define compiler_family gnu
%define c_f_ver 8
%define build_flavor ucx
%define build_static_devel 1
%{bcond_without hpc}
%endif
%if "%flavor" == "gnu8-hpc-testsuite"
%define compiler_family gnu
%define c_f_ver 8
%define testsuite 1
%define build_flavor ucx
%{bcond_without hpc}
%endif

%if "%flavor" == "gnu8-hpc-ofi"
%define compiler_family gnu
%define c_f_ver 8
%define build_flavor ofi
%define build_static_devel 1
%{bcond_without hpc}
%endif

%if "%flavor" == "gnu8-hpc-ofi-testsuite"
%define compiler_family gnu
%define c_f_ver 8
%define testsuite 1
%define build_flavor ofi
%{bcond_without hpc}
%endif

%if "%flavor" == "gnu9-hpc"
%define compiler_family gnu
%define c_f_ver 9
%define build_flavor ucx
%define build_static_devel 1
%{bcond_without hpc}
%endif
%if "%flavor" == "gnu9-hpc-testsuite"
%define compiler_family gnu
%define c_f_ver 9
%define testsuite 1
%define build_flavor ucx
%{bcond_without hpc}
%endif

%if "%flavor" == "gnu9-hpc-ofi"
%define compiler_family gnu
%define c_f_ver 9
%define build_flavor ofi
%define build_static_devel 1
%{bcond_without hpc}
%endif
%if "%flavor" == "gnu9-hpc-ofi-testsuite"
%define compiler_family gnu
%define c_f_ver 9
%define testsuite 1
%define build_flavor ofi
%{bcond_without hpc}
%endif

%if "%flavor" == "gnu10-hpc"
%define compiler_family gnu
%define c_f_ver 10
%define build_flavor ucx
%define build_static_devel 1
%{bcond_without hpc}
%endif

%if "%flavor" == "gnu10-hpc-testsuite"
%define compiler_family gnu
%define c_f_ver 10
%define testsuite 1
%define build_flavor ucx
%{bcond_without hpc}
%endif

%if "%flavor" == "gnu10-hpc-ofi"
%define compiler_family gnu
%define c_f_ver 10
%define build_flavor ofi
%define build_static_devel 1
%{bcond_without hpc}
%endif
%if "%flavor" == "gnu10-hpc-ofi-testsuite"
%define compiler_family gnu
%define c_f_ver 10
%define testsuite 1
%define build_flavor ofi
%{bcond_without hpc}
%endif

%if "%{build_flavor}" != "ucx"
%define pack_suff %{?build_flavor:-%{build_flavor}}
%endif

%if "%{build_flavor}" == "ucx"
%ifarch %ix86 %arm
# UCX is not available on 32b system so silently fallback
# on ch4:ofi
%define build_flavor ofi
%endif
%endif

%if %{without hpc}
%define module_name mpich%{?pack_suff}
%define p_prefix /usr/%_lib/mpi/gcc/%{module_name}
%define p_bindir  %{p_prefix}/bin
%define p_datadir %{p_prefix}/share
%define p_includedir %{p_prefix}/include
%define p_mandir  %{p_datadir}/man
%define p_libdir  %{p_prefix}/%{_lib}
%define p_libexecdir %{p_prefix}/%{_lib}
%define _moduledir /usr/share/modules/gnu-%{module_name}
%define package_name %{pname}%{?pack_suff}
%else
%{hpc_init -M -c %compiler_family %{?c_f_ver:-v %{c_f_ver}} -m mpich %{?pack_suff:-e %{build_flavor}} %{?mpi_f_ver:-V %{mpi_f_ver}}}
%define p_prefix   %{hpc_prefix}
%define p_bindir   %{hpc_bindir}
%define p_datadir  %{hpc_datadir}
%define p_includedir  %{hpc_includedir}
%define p_mandir   %{hpc_mandir}
%define p_libdir   %{hpc_libdir}
%define p_libexecdir  %{hpc_libexecdir}
%define package_name %{pname}%{?pack_suff}_%{_vers}-%{compiler_family}%{?c_f_ver}-hpc

%global hpc_mpich_dep_version %(VER=%{?m_f_ver}; echo -n ${VER})
%global hpc_mpich_dir mpich
%global hpc_mpich_pack_version %{hpc_mpich_dep_version}
ExcludeArch:    i586 %arm s390
%endif

Name:           %{package_name}%{?testsuite:-testsuite}
Version:        %{vers}
Release:        1.1
Summary:        High-performance and widely portable implementation of MPI
License:        MIT
Group:          Development/Libraries/Parallel
URL:            http://www.mpich.org/
Source0:        http://www.mpich.org/static/downloads/%{version}/mpich-%{vers}.tar.gz
Source1:        mpivars.sh
Source2:        mpivars.csh
Source3:        macros.hpc-mpich
Source100:      _multibuild
Patch1:         autogen-only-deal-with-json-yaksa-if-enabled.patch
Patch2:         autoconf-pull-dynamic-and-not-static-libs-from-pkg-config.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  fdupes
BuildRequires:  libjson-c-devel
BuildRequires:  libtool
BuildRequires:  pkg-config

%ifnarch s390 s390x %{arm} ppc64
BuildRequires:  valgrind-devel
%endif
%ifnarch s390 s390x armv7hl
BuildRequires:  libnuma-devel
%endif
BuildRequires:  libtool
BuildRequires:  libtool
BuildRequires:  mpi-selector
BuildRequires:  python3-devel

%if "%{build_flavor}" == "ofi"
BuildRequires:  libfabric-devel
%endif

%if "%{build_flavor}" == "ucx"
BuildRequires:  libucm-devel >= 1.7.0
BuildRequires:  libucp-devel >= 1.7.0
BuildRequires:  libucs-devel >= 1.7.0
BuildRequires:  libuct-devel >= 1.7.0
# UCX is only available for 64b archs
ExcludeArch:    %ix86 %arm
%endif

Provides:       mpi
%if %{without hpc}
BuildRequires:  Modules
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  mpi-selector
Requires:       mpi-selector
Requires(preun):mpi-selector
%else
BuildRequires:  %{compiler_family}%{?c_f_ver}-compilers-hpc-macros-devel
BuildRequires:  lua-lmod
BuildRequires:  suse-hpc
%hpc_requires
%endif

%if 0%{?testsuite}
BuildRequires:  %package_name = %{version}
%endif

%description
MPICH is a high performance and widely portable implementation of the Message
Passing Interface (MPI) standard.

The goals of MPICH are:

 * to provide an MPI implementation that efficiently supports different
   computation and communication platforms including commodity clusters
   (desktop systems, shared-memory systems, multicore architectures),
   high-speed networks and proprietary high-end computing systems
   (Blue Gene, Cray)
 * to enable cutting-edge research in MPI through an easy-to-extend modular
   framework for other derived implementations

%if 0%{!?testsuite:1}

%package devel
Summary:        SDK for MPICH %{?with_hpc:HPC} version %{version}
Group:          Development/Libraries/Parallel
Requires:       %{name} = %{version}
%if %{without hpc}
Requires:       libstdc++-devel
%else
%hpc_requires_devel
%endif
Requires:       %{name} = %{version}

%description devel
MPICH is a freely available, portable implementation of MPI, the
Standard for message-passing libraries. This package contains manpages,
headers and libraries needed for developing MPI applications.

This RPM contains all the wrappers necessary to compile, link, and run
Open MPI jobs.

%if %{with hpc}
%package        macros-devel
Summary:        HPC Macros for MPICH version %{version}
Group:          Development/Libraries/Parallel
Requires:       %{name}-devel = %{version}
Provides:       %{pname}-hpc-macros-devel = %{version}
Conflicts:      otherproviders(%{pname}-hpc-macros-devel)

%description macros-devel
HPC Macros for building RPM packages for MPICH version %{version}.
%endif

%if 0%{?build_static_devel}
%package        devel-static
Summary:        Static libraries for MPICH %{?with_hpc:HPC} version %{version}
Group:          Development/Libraries/Parallel
Requires:       %{name}-devel = %{version}

%description devel-static
MPICH is a freely available, portable implementation of MPI, the
Standard for message-passing libraries. This package contains manpages,
headers and libraries needed for developing MPI applications.

This RPM contains the static library files, which are packaged separately from
the dynamic library and headers.
%endif

%if %{with hpc}
%{hpc_master_package -L -a}
%{hpc_master_package -a devel}
%{hpc_master_package macros-devel}
%{hpc_master_package -a devel-static}
%endif # ?with_hpc

%endif # ! testsuite

%prep
echo FLAVOR %{flavor}
%if %{with hpc}
echo with HPC
%endif
%if %{without hpc}
echo without HPC
%endif
%autosetup -p0 -n mpich-%{version}%{?rc_ver}

# Make sure prebuilt dependencies are used and not mpich submodules
rm -R modules/{ucx,libfabric,json-c}

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects

# GCC10 needs an extra flag to allow badly passed parameters
%if 0%{?suse_version} > 1500 || 0%{?hpc_gnu_dep_version} >= 10
export FFLAGS="-fallow-argument-mismatch $FFLAGS"
export FCFLAGS="-fallow-argument-mismatch $FCFLAGS"
%endif

./autogen.sh --without-ucx --without-ofi --without-json
%{?with_hpc:%hpc_debug}
%if %{with hpc}
%{hpc_setup}
%{hpc_configure} \
%else
%configure \
    --prefix=%{p_prefix} \
    --exec-prefix=%{p_prefix} \
    --datadir=%{p_datadir} \
    --bindir=%{p_bindir} \
    --includedir=%{p_includedir} \
    --libdir=%{p_libdir} \
    --libexecdir=%{p_libexecdir} \
    --mandir=%{p_mandir} \
%endif
    --docdir=%{_datadir}/doc/%{name} \
    --disable-rpath      \
    --disable-wrapper-rpath      \
%if "%{build_flavor}" == "ofi"
   --with-ofi \
   --with-device=ch4:ofi \
%endif
%if "%{build_flavor}" == "ucx"
   --with-ucx \
   --with-device=ch4:ucx \
%endif
	CFLAGS="%optflags -fPIC"			\
	CXXLAGS="%optflags -fPIC"			\
	MPICHLIB_CFLAGS="%{optflags}"			\
	MPICHLIB_CXXFLAGS="%{optflags}"

make %{?_smp_mflags} VERBOSE=1

%install
make DESTDIR=%{buildroot} install

# sanitize .la files
list="$(find %{buildroot} -name "*.la" -printf "%%h\n" | sort | uniq)"
for dir in ${list}
do
    deps="${deps} -L${dir##%{buildroot}}"
done
for dir in ${list}
do
%if !0%{?build_static_devel}
    rm -f ${dir}/*.la
%else
    for file in ${dir}/*.la
    do
        sed -i -e "s@ [^[:space:]]*home[^[:space:]\']*@${deps}@" \
            -e "s@ [^[:space:]]*home[^[:space:]\']*@@g" \
            -e "s@-L.*.libs @@g" ${file}
    done
%endif
done
# sanitize .la files
%if !0%{?build_static_devel}
find %{buildroot} -name "*.a" -delete
%endif

%fdupes %{buildroot}%{p_mandir}
%fdupes %{buildroot}%{p_datadir}
%fdupes %{buildroot}%{p_libdir}/pkgconfig

%if 0%{?testsuite}
# Remove everything from testsuite package
# It is all contained by mpich packages
rm -rf %{buildroot}/*

%check
make check

%else

%if %{without hpc}
# make and install mpivars files
install -m 0755 -d %{buildroot}%{_bindir}
sed -e 's,prefix,%p_prefix,g' -e 's,libdir,%{p_libdir},g' %{S:1} > %{buildroot}%{p_bindir}/mpivars.sh
sed -e 's,prefix,%p_prefix,g' -e 's,libdir,%{p_libdir},g' %{S:2} > %{buildroot}%{p_bindir}/mpivars.csh

mkdir -p %{buildroot}%{_moduledir}

cat << EOF > %{buildroot}%{_moduledir}/%{version}
#%%Module
proc ModulesHelp { } {
        global dotversion
        puts stderr "\tLoads the gnu - mpich %{version}  Environment"
}

module-whatis  "Loads the gnu mpich %{version} Environment."
conflict gnu-mpich
prepend-path PATH %{%p_bindir}
prepend-path INCLUDE %{p_includedir}
prepend-path INCLUDE %{p_libdir}
prepend-path MANPATH %{p_mandir}
prepend-path LD_LIBRARY_PATH %{p_libdir}

EOF

cat << EOF > %{buildroot}%{_moduledir}/.version
#%%Module1.0
set ModulesVersion "%{version}"

EOF
%else # with hpc

install -d -m 755 %{buildroot}%{_rpmmacrodir}
cp %{S:3} %{buildroot}%{_rpmmacrodir}

%hpc_write_modules_files
#%%Module1.0#####################################################################

proc ModulesHelp { } {

puts stderr " "
puts stderr "This module loads the %{pname} library built with the %{compiler_family} toolchain."
puts stderr "\nVersion %{version}\n"

}
module-whatis "Name: %{pname} built with %{compiler_family} toolchain"
module-whatis "Version: %{version}"
module-whatis "Category: runtime library"
module-whatis "Description: %{SUMMARY:0}"
module-whatis "URL: %{url}"

set     version                     %{version}

prepend-path    PATH                %{hpc_bindir}
prepend-path    MANPATH             %{hpc_mandir}
prepend-path    LD_LIBRARY_PATH     %{hpc_libdir}
prepend-path    MODULEPATH          %{hpc_modulepath}
prepend-path    MPI_DIR             %{hpc_prefix}
%{hpc_modulefile_add_pkgconfig_path}

family "MPI"
EOF
cat <<EOF >  %{buildroot}/%{p_bindir}/mpivars.sh
%hpc_setup_compiler
module load %{hpc_mpi_family}%{?pack_suff}/%{version}
EOF
sed -e "s/export/setenv/" -e "s/=/ /" \
    %{buildroot}/%{p_bindir}/mpivars.sh > \
    %{buildroot}/%{p_bindir}/mpivars.csh
mkdir -p %{buildroot}%{_sysconfdir}/rpm
%endif # with hpc

find %{buildroot} -type f -name "*.la" -exec rm -f {} ';'

%fdupes -s %{buildroot}

%post
/sbin/ldconfig
%if %{without hpc}
# Always register. We might be already registered in the case of an udate
# but mpi-selector handles it fine
/usr/bin/mpi-selector \
        --register %{name}%{?pack_suff} \
        --source-dir %{p_bindir} \
        --yes
%endif

%postun
/sbin/ldconfig
%if %{without hpc}
# Only unregister when uninstalling
if [ "$1" = "0" ]; then
	/usr/bin/mpi-selector --unregister %{name}%{?pack_suff} --yes
	# Deregister the default if we are uninstalling it
	if [ "$(/usr/bin/mpi-selector --system --query)" = "%{name}%{?pack_suff}" ]; then
		/usr/bin/mpi-selector --system --unset --yes
	fi
fi
%else
%hpc_module_delete_if_default
%endif

%files
%defattr(-,root,root)
%doc CHANGES COPYRIGHT README README.envvar RELEASE_NOTES
%if %{without hpc}
%dir /usr/%_lib/mpi
%dir /usr/%_lib/mpi/gcc
%dir /usr/share/modules
%dir %{_moduledir}
%{_moduledir}
%else
%hpc_mpi_dirs
%hpc_modules_files
%endif
%doc %{_datadir}/doc/*
%dir %{p_prefix}
%dir %{p_bindir}
%dir %{p_datadir}
%dir %{p_includedir}
%dir %{p_mandir}
%dir %{p_mandir}/man1
%dir %{p_mandir}/man3
%dir %{p_libdir}
%{p_bindir}/*
%{p_mandir}/man1/*
%{p_libdir}/*.so.*

%files devel
%defattr(-,root,root)
%dir %{p_libdir}/pkgconfig
%{p_mandir}/man3/*
%{p_includedir}
%{p_libdir}/*.so
%{p_libdir}/pkgconfig/mpich.pc

%if 0%{?build_static_devel}
%files devel-static
%defattr(-,root,root)
%{p_libdir}/*.a
%endif

%if %{with hpc}
%files macros-devel
%defattr(-,root,root)
%config %{_rpmmacrodir}/macros.hpc-mpich
%endif # with hpc

%endif # !testsuite

%changelog
* Mon Aug 12 2024 Nicolas Morey <nicolas.morey@suse.com>
- Update to 4.2.2
  - Update embedded libfabric to v1.20.1 and fix compilation with GCC 14.
  - Fix dataloop support for MPIX_Type_iov routines
  - Fix crash in Hydra when system has many local ip addresses
  - Fix RMA fallback check in ch4:ofi netmod
  - Fix MPI_UNDEFINED handling in mpi_f08 module
  - Fix Slurm environment variable inheritance in Hydra
  - Fix multiple issues with large count support in ROMIO
  - Fix potential hang in init using PMIx client and nonstandard keys
  - Fix crash if PMIx client cannot get appnum from server during init
  - Fix other build errors and warnings
  - Disable flat_namespace to build libmpifort on macOS by default
  - Prefix warning messages with "MPICH"
  - Add --disable-doc configure option
  - Fix support for building MPICH Fortran support with Xcode 15 on macOS
  - Fix bug in MPI_WIN_SHARED_QUERY when window is not shared
  - Fix bug in ch4/ofi gpu pipelining
  - Fixes for Intel GPU support
  - Fix memory leak in ch4/shm collectives
  - Fix bug in MPI_COMM_SPLIT with intercommunicators and non-zero root
  - Fix bug in DAOS ROMIO driver
  - Fix bug in cycling error code array
  - Return an error if there is failure to create a datatype in mpi_f08
    module for noncontiguous user data
  - Return an error when shared memory segment creation fails
  - Complete support MPI 4.1 specification
  - Experimental thread communicator feature (e.g. MPIX_Threadcomm_init).
    See paper "Frustrated With MPI+Threads? Try MPIxThreads!",
    https://doi.org/10.1145/3615318.3615320.
  - Experimental datatype functions MPIX_Type_iov_len and MPIX_Type_Iov
  - Experimental op MPIX_EQUAL for MPI_Reduce and MPI_Allreduce (intra
    communicator only)
  - Use --with-{pmi,pmi2,pmix]=[path] to configure external PMI library.
    Convenience options for Slurm and cray deprecated. Use --with-pmi=oldcray
    for older Cray environment.
  - Error checking default changed to runtime (used to be all).
  - Use the error handler bound to MPI_COMM_SELF as the default error handler.
  - Use ierror instead of ierr in "use mpi" Fortran interface. This affects
    user code if they call with explicit keyword, e.g. call MPI_Init(ierr=arg).
    "ierror" is the correct name specified in the MPI specification. We only
    added subroutine interface in "mpi.mod" since 4.1.
  - Handle conversion functions, such as MPI_Comm_c2f, MPI_Comm_f2c, etc., are
    no longer macros. MPI-4.1 require these to be actual functions.
  - Yaksa updated to auto detect the GPU architecture and only build for
    the detected arch. This applies to CUDA and HIP support.
  - MPI_Win_shared_query can be used on windows created by MPI_Win_create,
    MPI_Win_allocate, in addition to windows created by MPI_Win_allocate_shared.
    MPI_Win_allocate will create shared memory whenever feasible, including between
    spawned processes on the same node.
  - Fortran mpi.mod support Type(c_ptr) buffer output for MPI_Alloc_mem,
    MPI_Win_allocate, and MPI_Win_allocate_shared.
  - New functions added in MPI-4.1: MPI_Remove_error_string, MPI_Remove_error_code,
    and MPI_Remove_error_class
  - New functions added in MPI-4.1: MPI_Request_get_status_all,
    MPI_Request_get_status_any, and MPI_Request_get_status_some.
  - New function added in MPI-4.1: MPI_Type_get_value_index.
  - New functions added in MPI-4.1: MPI_Comm_attach_buffer, MPI_Session_attach_buffer,
    MPI_Comm_detach_buffer, MPI_Session_detach_buffer,
    MPI_Buffer_flush, MPI_Comm_flush_buffer, MPI_Session_flush_buffer,
    MPI_Buffer_iflush, MPI_Comm_iflush_buffer, and MPI_Session_iflush_buffer.
    Also added constant MPI_BUFFER_AUTOMATIC to allow automatic buffers.
  - Support for "mpi_memory_alloc_kinds" info key. Memory allocation kind
    requests can be made via argument to mpiexec, or as info during
    session creation. Kinds supported are "mpi" (with standard defined
    restrictors) and "system". Queries for supported kinds can be made on
    MPI objects such as sessions, comms, windows, or files. MPI 4.1 states
    that supported kinds can also be found in MPI_INFO_ENV, but it was
    decided at the October 2023 meeting that this was a mistake and will
    be removed in an erratum.
  - Fix potential crash in GPU memory hooks
* Tue Jun 25 2024 Nicolas Morey <nicolas.morey@suse.com>
- Remove unneeded sysfsutil dependency
- Do no build hpc flavours on 32b systems
* Wed May 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro: allows us to eliminate usage of deprecated
  %%patchN syntax.
* Tue Jul 25 2023 Nicolas Morey <nicolas.morey@suse.com>
- Update to 4.1.2
  - Update UCX module to includes fixes for building with GCC 13
  - Update libfabric module to 1.18.0 with additional fixes for building
    with recent versions of LLVM/Clang
  - Fix compiler wrapper scripts to be compatible with CUDA memory hooks
  - Fix MPIX_WAITALL_ENQUEUE to make a copy of the input request array
  - Fix bug in MPI_ALLREDUCE that could result in ranks receiving
    different floating point values
  - Fix potential deadlock when progressing RMA windows
  - Fix potential crash in MPI_REDUCE with non-zero root and MPI_IN_PLACE
  - Fix potential crash during probe with libfabric CXI provider
  - Fix MPI_PARRIVED when the partitioned request is inactive
  - Fix potential bug when an attribute delete callback deletes another
    attribute on the same object
  - Fix build issue in ROMIO Lustre driver
  - Improve Fortran 2008 binding support detection during configure
  - Report an error if collective tuning json file fails to open
  - Several fixes for testsuite programs and build configuration
  - Update embedded UCX module to 1.13.1. Fixes a build issue with
    binutils >= 2.39.
  - Update yaksa module. Support explicit NVCC setting by the user. Fixes
    a build issue when there is no libtool available in PATH.
  - Fix ch4:ucx initialization when configured with
  - -enable-ch4-vci-method=implicit.
  - Fix potential error handler leak during MPI_SESSION_FINALIZE
  - Fix value of MPI_UNDEFINED in mpif.h binding
  - Fix MPI_IALLTOALLW with MPI_IN_PLACE
  - Fix send attribute handling in IPC path
  - Fix a bug in persistent MPI_ALLGATHER
  - Fix tests for use with non-MPICH libraries
  - Add missing MPI_T_ERR_NOT_ACCESSIBLE error code
  - Fix manpages for MPIX functions
  - Thread-cs in ch4 changed to per-vci.
  - Testsuite (test/mpi) is configured separately from mpich configure.
  - Added options in autogen to accelerate CI builds, including using pre-built
    sub-modules. Added -yaksa-depth option to generate shallower yaksa pup code
    for faster build and smaller binaries.
  - Support singleton init using hydra.
  - Generate mpi.mod Fortran interfaces using Python 3. For many compilers,
    including gfortran, flags such as -fallow-mismatched-args is no longer
    necessary.
  - Fixed message queue debugger interface in ch4.
  - PMI (src/pmi) is refactored as a subdir and can be separately distributed.
  - Added MPIX_Comm_get_failed.
  - Experimental MPIX stream API to enable explicit thread contexts.
  - Experimental MPIX gpu enqueue API. It currently only supports CUDA streams.
  - Delays GPU resource allocation in yaksa.
  - CH3 nemesis ofi netmod is removed.
  - New collective algorithms. All collective algorithms are listed in
    src/mpi/coll/coll_algorithms.txt
  - Removed hydra2. We will port unique features of hydra2, including
    tree-launching, to hydra in the future release.
  - Added in-repository wiki documentation.
  - Added stream workq to support optimizations for enqueue operations.
  - Better support for large count APIs by eliminating type conversion issues.
  - Hydra now uses libpmi (src/pmi) for handling PMI messages.
  - Many bug fixes and enhancements.
- Refresh autogen-only-deal-with-json-yaksa-if-enabled.patch
* Tue Oct 25 2022 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Revert use of internal PMIx and hwloc library
  - Using external libraries disables the build of all process managers
* Mon Oct 17 2022 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Disable valgrind on ppc64 to fix build dependency issues.
- Add _constraints to fix compilation running out of disk space.
* Thu Sep 29 2022 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to 4.0.2
  - Fix support for dynamic process functionality with PMI2 clients
  - Fix non-zero appnum bug in PMI2 server in Hydra
  - Fix MPI_Op support for types created with MPI_Type_create_f90_xxx
  - Fix Level Zero properties initialization in MPL.
  - Use standard names for CPU affinity functions with POSIX
    threads.
  - Add elemental to eq/neq operators in Fortran 2008 binding
* Wed Jul  6 2022 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Switch to external hwloc, and PMIx
- On 32b systems, use ofi instead of verbs flavor by default
* Mon Mar  7 2022 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to mpich 4.0.1 (bsc#1194369)
  - All MPI-4 APIs have been implemented. Major MPI-4 features include MPI
    sessions, partitioned point-to-point communications, events in the MPI tool
    information interface, large-count functions, persistent collectives,
    MPI_Comm_idup_with_info, MPI_Isendrecv and MPI_Isendrecv_replace,
    MPI_Info_get_string, MPI_Comm_split_type with new split_type --
    MPI_COMM_TYPE_HW_GUIDED and MPI_COMM_TYPE_HW_UNGUIDED.
  - Add MPIX_Delete_error_{class,code,string}.
  - MPI_Info objects can be accessed before MPI_Init{_thread}.
  - Drop support for UCX version < 1.7.0.
  - Multi-NIC support in ch4:ofi.
  - Extend IPC to support non-contig datatypes.
  - Many bug fixes and code clean-ups.
- Drop 0001-Drop-real128.patch as it was fixed upstream
- Refresh autogen-only-deal-with-json-yaksa-if-enabled.patch
  against latest sources
* Wed Jan 12 2022 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to mpich 3.4.3
  - Fix nemesis shm bug on systems with weak memory consistency
  - Fix progress issue in ch4:ucx finalize
  - Fix nonblocking collective issue during finalize
  - Fix predefined datatype handle leaks
  - Fix bug in topology-aware communicator creation
  - Fix Slurm nodelist parsing
  - Hydra help message improvements
* Tue Oct 19 2021 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Move rpm macros to %%_rpmmacrodir (bsc#1191385)
* Tue Aug 24 2021 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to mpich 3.4.2
  - Update embedded hwloc to version 2.4.1. Fixes a build issue on
    systems with OpenCL.
  - Fix additional bugs in GPU-aware nonblocking op collectives
  - Fix support for GNI provider in ch4:ofi netmod
  - Fix bug in dynamic window memory registration with ch4:ofi netmod
  - Fix bug in persistent pt2pt when used with MPI_PROC_NULL
  - Fix bug in hydra nameserver when freeing published entries
  - Fix bugs in XPMEM support
  - Fix bug in MPI_Comm_spawn_multiple where non-root args were not ignored
* Sun Jun 13 2021 Christian Boltz <suse-beta@cboltz.de>
- don't own /usr/share/doc (owned by "filesystem") to avoid conflict on install
* Tue Mar 30 2021 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to mpich 3.4.1
  - ch4 replaces ch3 as the default device configuration. If no network
    module is specified at configuration-time, MPICH will search the
    user environment in order to select one to build. The user will be
    prompted to choose if no preferred network library is dectected.
  - Add support for XPMEM.
  - Add support for multiple virtual communication interfaces for more
    efficient MPI_THREAD_MULTIPLE (experimental).
  - Add support for Arm compiler toolchain
  - Add support for flang/f18 Fortran compiler
  - See CHANGES for the complete list of CHANGES
- Changed MPI interface in mpich package
  - 64bit archs use ch4:ucx
  - 32bit archs use ch3:nemesis (verbs)
- Drop patches merged upstream:
  - ch3-fix-improper-error-handling-from-MPL_get_sockaddr.patch
  - opmi-fix-a-wrong-condition-checking-return-of-MPL_get_sockaddr.patch
- Add patches to make sure built is used with the proper system libraries
  and not the embedded ones:
  - autogen-only-deal-with-json-yaksa-if-enabled.patch
  - autoconf-pull-dynamic-and-not-static-libs-from-pkg-config.patch
- Refresh 0001-Drop-real128.patch against latest sources
* Sun Nov 29 2020 Egbert Eich <eich@suse.com>
- HPC: Fix environment module settings for MANPATH.
* Sat Jul 25 2020 Egbert Eich <eich@suse.com>
- For HPC builds check for gnu compiler suite version >= 10 and
  set -fallow-argument-mismatch.
* Thu Jul 23 2020 Egbert Eich <eich@suse.com>
- Add build support for gcc8/9/10 to HPC build (bsc#1174439).
* Tue Jun  9 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Fix compilation with GCC10 by adding -fallow-argument-mismatch to FFLAGS
* Tue Apr 14 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Add ch3-fix-improper-error-handling-from-MPL_get_sockaddr.patch and
  pmi-fix-a-wrong-condition-checking-return-of-MPL_get_sockaddr.patch to fix crash when
  using getsockaddr (bsc#1168092)
* Thu Nov 28 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to mpich 3.3.2 (jsc#SLE-8574)
  - See CHANGES for a list of changes
* Thu Sep 26 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to mpich 3.3.1 (jsc#SLE-8574)
  - See CHANGES for a list of changes
- Drop 0001-Drop-GCC-check.patch as it was picked upstream
- Add 0001-Drop-real128.patch to fix a compilation error on armv7
* Thu Sep 26 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Fix LTO support in archive file
* Fri May  3 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to mpich 3.3
  - See CHANGES for a list of changes
* Thu Mar 21 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Add patch to remove obsolete GCC check (bnc#1129421). It also patches
  autogen.sh to get the autotools working in SLE12SP4.
  * 0001-Drop-GCC-check.patch
- Force to re-run autotools to generate properly the files after
  patching src/binding/cxx/buildiface
* Sun Nov 18 2018 eich@suse.com
- Add macro _hpc_mpich_modules for modules support (bsc#1116458).
* Mon Sep 10 2018 nmoreychaisemartin@suse.com
- Remove bashism in postun scriptlet
* Wed Sep  5 2018 nmoreychaisemartin@suse.com
- Fix handling of mpi-selector during updates (bsc#1098653)
* Sun Aug 19 2018 eich@suse.com
- macros.hpc-mpich:
  replace %%%%compiler_family by %%%%hpc_compiler_family
* Sun Apr 22 2018 eich@suse.com
- Remove 'BuildRequires: Modules' for HPC builds: it conflicts
  with lmod (boo#1089970).
* Fri Feb  9 2018 cgoll@suse.com
- Fix summary in module files (bnc#1080259)
* Tue Jan 30 2018 eich@suse.com
- Use macro in mpivars.(c)sh to be independent of changes to the module
  setup for the compiler (boo#1078364).
* Fri Jan 19 2018 nmoreychaisemartin@suse.com
- Update to mpich 3.2.1
  - Bug fixes
  - No release notes available
* Fri Jan  5 2018 eich@suse.com
- Add gcc7 as additional compiler flavor for HPC on SLES.
- Fix library package requires - use HPC macro (boo#1074890).
- Fix mpich HPC installation path in spec file.
- Fix hpc macros: add %%mpich_requires.
* Thu Oct 26 2017 nmoreychaisemartin@suse.com
- Add HPC specific build targets using environment modules (Fate#323977).
* Tue Sep 12 2017 nmoreychaisemartin@suse.com
- Drop unnecessary dependency to xorg-x11-devel
* Thu Jul 13 2017 nmoreychaisemartin@suse.com
- Add LD_LIBRARY_PATH to mpivars.sh and mpivars.csh
* Thu Jul 13 2017 nmoreychaisemartin@suse.com
- Disable rpath in pkgconfig files
* Wed Jul  5 2017 nmoreychaisemartin@suse.com
- Register mpich package to mpi-selector
- Remove redondant configure options already passed by %%configure
* Mon Jul  3 2017 nmoreychaisemartin@suse.com
- Fix compilation for aarch64
- Build multiple flavour of mpich (psm, psm2, tessuite)
- Update to mpich 3.2
  * see CHANGES file for all details, some pertinent changes are:
  - Added support for MPI-3.1 features including nonblocking collective I/O,
    address manipulation routines, thread-safety for MPI initialization,
    pre-init functionality, and new MPI_T routines to look up variables
    by name.
  - Fortran 2008 bindings are enabled by default and fully supported.
  - Completely revamped RMA infrastructure including several
    scalability improvements, performance improvements, and bug fixes.
  - Added experimental support for Open Fabrics Interfaces (OFI) version 1.0.0.
    https://github.com/ofiwg/libfabric (thanks to Intel for code contribution)
* Thu Jan  8 2015 kkhere.geo@gmail.com
- Update to 3.1.3
  * see CHANGES file for all details, some pertinent changes are:
  - [3.1.2] MPI-3 support for Blue Gene/Q and ppc64le support.
  - [3.1.2] Fixes and testcases for Fortran 2008 bindings.
  - [3.1.1] Removal of the mpd process manager.
  - [3.1] MPICH now supports operations on very large datatypes (those that
    describe more than 32 bits of data).
* Fri Oct  4 2013 mvyskocil@suse.com
- Update to 3.0.4
  * too many changes to list, see CHANGES file
- Dropped pointless patches:
  * alog-bufferoverflow.patch
  * gcc4.dif
  * gfortran.patch
  * mpeinstall.patch
  * mpich-1.2.6.dif
  * mpich-1.2.6_implicit_declarations.diff
  * mpich-1.2.6-limits.patch
  * mpich-1.2.7_bsendutil2.c_uninitialized_variables.patch
  * mpich-1.2.7p1-iostream.dif
  * mpich-fix_headers.diff
  * mpich-hostent.patch
  * mpich-mpiman.patch
- Add mpich-modules.patch (from Fedora)
- Add package autoload installs mpich's profiles
- Moved documentation to doc subpackage
- Call make check during build
* Mon Mar  5 2012 cfarrell@suse.com
- license update: SUSE-Permissive
  Use a license from http://is.gd/CIdCM7 - if there is no corresponding
  entry on spdx.org/licenses use the proprietary SUSE- prefix until the
  license is accepted upstream
* Wed Nov 23 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Wed Nov 24 2010 ro@suse.de
- compress manpages ourselves
  (Check is gone and brp-compress does not look under /opt)
* Thu Mar  4 2010 coolo@novell.com
- extend bufferoverflow patch to fix also clog
* Fri Jan 22 2010 coolo@novell.com
- use gnu extensions to fix implicit declarations
* Fri Jul 31 2009 aj@suse.de
- Cleanup some rpmlint warnings in spec file.
* Fri Jul 31 2009 aj@suse.de
- Fix compilation with current glibc (mpich-hostent.patch)
* Tue Jan 29 2008 aj@suse.de
- Fix c++ compilation.
* Thu May 24 2007 stbinner@suse.de
- add missing %%run_ldconfig calls
- use %%fdupes
* Sat Mar 31 2007 aj@suse.de
- Remove unnneeded BuildRequires.
* Wed Mar  8 2006 mrueckert@suse.de
- move the man pages for the compilers into the devel package
  aswell (#132558)
* Fri Jan 27 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 24 2006 rguenther@suse.de
- make configury work with gfortran.
- re-enable fortran support and update packaged files.
* Mon Jan 16 2006 mrueckert@suse.de
- update to version 1.2.7p1
- added mpich-1.2.7_bsendutil2.c_uninitialized_variables.patch
* Wed Dec 21 2005 ro@suse.de
- addded library .so symlinks to filelist
* Mon Sep 19 2005 mrueckert@suse.de
- Fixed compiler warnings about implicit declarations.
- fixed patches to apply cleanly against 1.2.7
* Fri Aug 19 2005 mrueckert@suse.de
- mpiman now defaults to "man" instead of "xman"
  now it works without passing any parameter too.
* Mon Jul  4 2005 mrueckert@suse.de
- Updated to version 1.2.7
- Added small patch against a buffer overflow in the log handler.
- Compile with -fno-strict-aliasing
- Use RPM_OPT_FLAGS
* Sun Apr 24 2005 aj@suse.de
- Compile with GCC4, disable g77.
* Sun Aug 15 2004 nashif@suse.de
- Update to 1.2.6
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Mon Jan  5 2004 nashif@suse.de
- update to 1.5.2.2
- fixed bug #33381:  unnecessary s bit on mpdcon
* Fri Jun 13 2003 kukuk@suse.de
- Add missing directories to filelist
* Wed May 28 2003 nashif@suse.de
- Compile ch_p4mpd in addition to default ch_p4
- Reworked file list
* Wed Jan  8 2003 nashif@suse.de
- Update to 1.2.5
* Wed Nov 20 2002 ro@suse.de
- use java2
* Sun Aug  4 2002 nashif@suse.de
- Update to 1.2.4
- Move to /opt to avoid path problems with lib64
- re-added module file
* Sun Jun 23 2002 ro@suse.de
- fix permissions for doc directories
* Tue Jun 18 2002 mls@suse.de
- delete bogus config.* files in examples directory
* Thu May 16 2002 meissner@suse.de
- Another fix for lib64 (or we include %%buildroot paths in mpicc)
* Mon May 13 2002 ro@suse.de
- fix for lib64
* Sat Feb  9 2002 nashif@suse.de
- -doc provides and obsoletes -manpages
* Thu Feb  7 2002 nashif@suse.de
- Use RPM_BUILD_ROOT variable instead of actual value
* Sat Feb  2 2002 nashif@suse.de
- Removed rpm_build_root references from scripts
* Fri Feb  1 2002 nashif@suse.de
- Update to version 1.2.3
- splitted package to devel and doc
* Thu Apr 12 2001 nashif@suse.de
- Applied cummulative patches upto bug #5906
* Wed Mar  7 2001 nashif@suse.de
- Fixed order of patches in spec file
- Fixed script in spec to link binaries in /usr/bin
* Tue Mar  6 2001 nashif@suse.de
- Update with latest patches (patch.all)
- removed all mpi* from /usr/bin (Conflicts with other MPIs)
- Added mpich module configuration file for (module load mpich), which
  requires environment-modules package.
- Fixed shared lib path in mpif77,90
* Tue Mar  6 2001 schwab@suse.de
- Build with --enable-sharedlib to get something that can be linked
  into a shared library.
- Add %%suse_update_config.
* Sat Feb 17 2001 nashif@suse.de
- Fixed va_arg arguments
- Update to latest patchlevel
* Fri Nov 17 2000 nashif@suse.de
- Added mpe support
* Thu Nov 16 2000 nashif@suse.de
- Applied latest cummulative patch
- Changed sub-package name: mpichman -> mpich-manpages
* Sun Oct 29 2000 nashif@suse.de
- Update to version 1.2.1
* Fri Mar 31 2000 nadvornik@suse.cz
- removed directories owned by aaa_dir
* Tue Jan 25 2000 nashif@suse.de
- Applied patches 4992 and 4997
* Mon Jan 17 2000 nashif@suse.de
- Updated to 1.2.0
- moved manpages to /usr/share
* Sun Nov  7 1999 nashif@suse.de
-   Organised spec file
-   fixed spec file
* Thu Oct  7 1999 nashif@suse.de
-   Minor link fixes and directory reloacation
* Thu Sep 30 1999 nashif@suse.de
-  Added mpichman: a new subpackage for the manual pages to avoid
  conflict with LAM
-  moved configuration files to /etc/mpich
-  Now it should work side by side with LAM
* Tue Sep 28 1999 nashif@suse.de
-  Removed MPE from package: using old tk
* Mon Sep 27 1999 nashif@suse.de
-  MPICH - Message Passing Interface Implementation 1.1.2
